==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/IntegrationRuntimeSsisPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeSsisPropertiesArgs.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.IntegrationRuntimeEdition
import com.pulumi.azurenative.datafactory.kotlin.enums.IntegrationRuntimeLicenseType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * SSIS properties for managed integration runtime.
 * @property catalogInfo Catalog information for managed dedicated integration runtime.
 * @property credential The credential reference containing authentication information.
 * @property customSetupScriptProperties Custom setup script properties for a managed dedicated integration runtime.
 * @property dataProxyProperties Data proxy properties for a managed dedicated integration runtime.
 * @property edition The edition for the SSIS Integration Runtime
 * @property expressCustomSetupProperties Custom setup without script properties for a SSIS integration runtime.
 * @property licenseType License type for bringing your own license scenario.
 * @property packageStores Package stores for the SSIS Integration Runtime.
 */
public data class IntegrationRuntimeSsisPropertiesArgs(
    public val catalogInfo: Output<IntegrationRuntimeSsisCatalogInfoArgs>? = null,
    public val credential: Output<CredentialReferenceArgs>? = null,
    public val customSetupScriptProperties: Output<IntegrationRuntimeCustomSetupScriptPropertiesArgs>? =
        null,
    public val dataProxyProperties: Output<IntegrationRuntimeDataProxyPropertiesArgs>? = null,
    public val edition: Output<Either<String, IntegrationRuntimeEdition>>? = null,
    public val expressCustomSetupProperties: Output<List<Any>>? = null,
    public val licenseType: Output<Either<String, IntegrationRuntimeLicenseType>>? = null,
    public val packageStores: Output<List<PackageStoreArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeSsisPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeSsisPropertiesArgs =
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeSsisPropertiesArgs.builder()
            .catalogInfo(catalogInfo?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .credential(credential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .customSetupScriptProperties(
                customSetupScriptProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .dataProxyProperties(
                dataProxyProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .edition(
                edition?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .expressCustomSetupProperties(
                expressCustomSetupProperties?.applyValue({ args0 ->
                    args0.map({ args0 -> args0 })
                }),
            )
            .licenseType(
                licenseType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .packageStores(
                packageStores?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [IntegrationRuntimeSsisPropertiesArgs].
 */
@PulumiTagMarker
public class IntegrationRuntimeSsisPropertiesArgsBuilder internal constructor() {
    private var catalogInfo: Output<IntegrationRuntimeSsisCatalogInfoArgs>? = null

    private var credential: Output<CredentialReferenceArgs>? = null

    private var customSetupScriptProperties:
        Output<IntegrationRuntimeCustomSetupScriptPropertiesArgs>? = null

    private var dataProxyProperties: Output<IntegrationRuntimeDataProxyPropertiesArgs>? = null

    private var edition: Output<Either<String, IntegrationRuntimeEdition>>? = null

    private var expressCustomSetupProperties: Output<List<Any>>? = null

    private var licenseType: Output<Either<String, IntegrationRuntimeLicenseType>>? = null

    private var packageStores: Output<List<PackageStoreArgs>>? = null

    /**
     * @param value Catalog information for managed dedicated integration runtime.
     */
    @JvmName("psdbeuwybfsjorso")
    public suspend fun catalogInfo(`value`: Output<IntegrationRuntimeSsisCatalogInfoArgs>) {
        this.catalogInfo = value
    }

    /**
     * @param value The credential reference containing authentication information.
     */
    @JvmName("ilyeuklwexqvgfhm")
    public suspend fun credential(`value`: Output<CredentialReferenceArgs>) {
        this.credential = value
    }

    /**
     * @param value Custom setup script properties for a managed dedicated integration runtime.
     */
    @JvmName("vaehiolghnjbvlsm")
    public suspend
    fun customSetupScriptProperties(`value`: Output<IntegrationRuntimeCustomSetupScriptPropertiesArgs>) {
        this.customSetupScriptProperties = value
    }

    /**
     * @param value Data proxy properties for a managed dedicated integration runtime.
     */
    @JvmName("ekwfgslfnweeakep")
    public suspend
    fun dataProxyProperties(`value`: Output<IntegrationRuntimeDataProxyPropertiesArgs>) {
        this.dataProxyProperties = value
    }

    /**
     * @param value The edition for the SSIS Integration Runtime
     */
    @JvmName("kehqqsknodohtdxq")
    public suspend fun edition(`value`: Output<Either<String, IntegrationRuntimeEdition>>) {
        this.edition = value
    }

    /**
     * @param value Custom setup without script properties for a SSIS integration runtime.
     */
    @JvmName("ypammglyshidgdoa")
    public suspend fun expressCustomSetupProperties(`value`: Output<List<Any>>) {
        this.expressCustomSetupProperties = value
    }

    @JvmName("uevlriysysymqwrk")
    public suspend fun expressCustomSetupProperties(vararg values: Output<Any>) {
        this.expressCustomSetupProperties = Output.all(values.asList())
    }

    /**
     * @param values Custom setup without script properties for a SSIS integration runtime.
     */
    @JvmName("ewyyyspicobxokib")
    public suspend fun expressCustomSetupProperties(values: List<Output<Any>>) {
        this.expressCustomSetupProperties = Output.all(values)
    }

    /**
     * @param value License type for bringing your own license scenario.
     */
    @JvmName("rwxthcgvqxniipon")
    public suspend fun licenseType(`value`: Output<Either<String, IntegrationRuntimeLicenseType>>) {
        this.licenseType = value
    }

    /**
     * @param value Package stores for the SSIS Integration Runtime.
     */
    @JvmName("bmluutophinmmkmq")
    public suspend fun packageStores(`value`: Output<List<PackageStoreArgs>>) {
        this.packageStores = value
    }

    @JvmName("qpjqymsgqqmmtpql")
    public suspend fun packageStores(vararg values: Output<PackageStoreArgs>) {
        this.packageStores = Output.all(values.asList())
    }

    /**
     * @param values Package stores for the SSIS Integration Runtime.
     */
    @JvmName("buxgecrtiqexeiug")
    public suspend fun packageStores(values: List<Output<PackageStoreArgs>>) {
        this.packageStores = Output.all(values)
    }

    /**
     * @param value Catalog information for managed dedicated integration runtime.
     */
    @JvmName("hwmhswqmebnrnuva")
    public suspend fun catalogInfo(`value`: IntegrationRuntimeSsisCatalogInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.catalogInfo = mapped
    }

    /**
     * @param argument Catalog information for managed dedicated integration runtime.
     */
    @JvmName("ndrqsanggsrdqonj")
    public suspend
    fun catalogInfo(argument: suspend IntegrationRuntimeSsisCatalogInfoArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeSsisCatalogInfoArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.catalogInfo = mapped
    }

    /**
     * @param value The credential reference containing authentication information.
     */
    @JvmName("leoyivocrpdcbvye")
    public suspend fun credential(`value`: CredentialReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.credential = mapped
    }

    /**
     * @param argument The credential reference containing authentication information.
     */
    @JvmName("upeyvachvghxkrxs")
    public suspend fun credential(argument: suspend CredentialReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = CredentialReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.credential = mapped
    }

    /**
     * @param value Custom setup script properties for a managed dedicated integration runtime.
     */
    @JvmName("deuadmmwmcyowkqm")
    public suspend
    fun customSetupScriptProperties(`value`: IntegrationRuntimeCustomSetupScriptPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customSetupScriptProperties = mapped
    }

    /**
     * @param argument Custom setup script properties for a managed dedicated integration runtime.
     */
    @JvmName("vgchwgyiastwhpot")
    public suspend
    fun customSetupScriptProperties(argument: suspend IntegrationRuntimeCustomSetupScriptPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeCustomSetupScriptPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.customSetupScriptProperties = mapped
    }

    /**
     * @param value Data proxy properties for a managed dedicated integration runtime.
     */
    @JvmName("vsloqokdnukngwxv")
    public suspend fun dataProxyProperties(`value`: IntegrationRuntimeDataProxyPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataProxyProperties = mapped
    }

    /**
     * @param argument Data proxy properties for a managed dedicated integration runtime.
     */
    @JvmName("kmhgkqohqbiwiggy")
    public suspend
    fun dataProxyProperties(argument: suspend IntegrationRuntimeDataProxyPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeDataProxyPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dataProxyProperties = mapped
    }

    /**
     * @param value The edition for the SSIS Integration Runtime
     */
    @JvmName("xomgbvypiderikmk")
    public suspend fun edition(`value`: Either<String, IntegrationRuntimeEdition>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.edition = mapped
    }

    /**
     * @param value The edition for the SSIS Integration Runtime
     */
    @JvmName("farktrccnxyxqtkw")
    public fun edition(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IntegrationRuntimeEdition>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.edition = mapped
    }

    /**
     * @param value The edition for the SSIS Integration Runtime
     */
    @JvmName("vkraoxaghyljctcb")
    public fun edition(`value`: IntegrationRuntimeEdition) {
        val toBeMapped = Either.ofRight<String, IntegrationRuntimeEdition>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.edition = mapped
    }

    /**
     * @param value Custom setup without script properties for a SSIS integration runtime.
     */
    @JvmName("bfenpgtnyvydtrxn")
    public suspend fun expressCustomSetupProperties(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expressCustomSetupProperties = mapped
    }

    /**
     * @param values Custom setup without script properties for a SSIS integration runtime.
     */
    @JvmName("wnjunrsbykgevigj")
    public suspend fun expressCustomSetupProperties(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.expressCustomSetupProperties = mapped
    }

    /**
     * @param value License type for bringing your own license scenario.
     */
    @JvmName("loacyikxjomnlcgj")
    public suspend fun licenseType(`value`: Either<String, IntegrationRuntimeLicenseType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.licenseType = mapped
    }

    /**
     * @param value License type for bringing your own license scenario.
     */
    @JvmName("ulmiebqourarbetk")
    public fun licenseType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IntegrationRuntimeLicenseType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.licenseType = mapped
    }

    /**
     * @param value License type for bringing your own license scenario.
     */
    @JvmName("omfutegtgkfvsxhw")
    public fun licenseType(`value`: IntegrationRuntimeLicenseType) {
        val toBeMapped = Either.ofRight<String, IntegrationRuntimeLicenseType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.licenseType = mapped
    }

    /**
     * @param value Package stores for the SSIS Integration Runtime.
     */
    @JvmName("piedlpfhsqqkxbtr")
    public suspend fun packageStores(`value`: List<PackageStoreArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.packageStores = mapped
    }

    /**
     * @param argument Package stores for the SSIS Integration Runtime.
     */
    @JvmName("ucrgbmnydxdjjiww")
    public suspend fun packageStores(argument: List<suspend PackageStoreArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PackageStoreArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.packageStores = mapped
    }

    /**
     * @param argument Package stores for the SSIS Integration Runtime.
     */
    @JvmName("smijnxfoxshaqjys")
    public suspend fun packageStores(vararg argument: suspend PackageStoreArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            PackageStoreArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.packageStores = mapped
    }

    /**
     * @param argument Package stores for the SSIS Integration Runtime.
     */
    @JvmName("orxyynodmxxkkjai")
    public suspend fun packageStores(argument: suspend PackageStoreArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PackageStoreArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.packageStores = mapped
    }

    /**
     * @param values Package stores for the SSIS Integration Runtime.
     */
    @JvmName("xiannghhiaevyhpb")
    public suspend fun packageStores(vararg values: PackageStoreArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.packageStores = mapped
    }

    internal fun build(): IntegrationRuntimeSsisPropertiesArgs = IntegrationRuntimeSsisPropertiesArgs(
        catalogInfo = catalogInfo,
        credential = credential,
        customSetupScriptProperties = customSetupScriptProperties,
        dataProxyProperties = dataProxyProperties,
        edition = edition,
        expressCustomSetupProperties = expressCustomSetupProperties,
        licenseType = licenseType,
        packageStores = packageStores,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/IntegrationRuntimeSsisPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeSsisPropertiesArgs.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.IntegrationRuntimeEdition
import com.pulumi.azurenative.datafactory.kotlin.enums.IntegrationRuntimeLicenseType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * SSIS properties for managed integration runtime.
 * @property catalogInfo Catalog information for managed dedicated integration runtime.
 * @property credential The credential reference containing authentication information.
 * @property customSetupScriptProperties Custom setup script properties for a managed dedicated integration runtime.
 * @property dataProxyProperties Data proxy properties for a managed dedicated integration runtime.
 * @property edition The edition for the SSIS Integration Runtime
 * @property expressCustomSetupProperties Custom setup without script properties for a SSIS integration runtime.
 * @property licenseType License type for bringing your own license scenario.
 * @property packageStores Package stores for the SSIS Integration Runtime.
 */
public data class IntegrationRuntimeSsisPropertiesArgs(
    public val catalogInfo: Output<IntegrationRuntimeSsisCatalogInfoArgs>? = null,
    public val credential: Output<CredentialReferenceArgs>? = null,
    public val customSetupScriptProperties: Output<IntegrationRuntimeCustomSetupScriptPropertiesArgs>? =
        null,
    public val dataProxyProperties: Output<IntegrationRuntimeDataProxyPropertiesArgs>? = null,
    public val edition: Output<Either<String, IntegrationRuntimeEdition>>? = null,
    public val expressCustomSetupProperties: Output<List<Any>>? = null,
    public val licenseType: Output<Either<String, IntegrationRuntimeLicenseType>>? = null,
    public val packageStores: Output<List<PackageStoreArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeSsisPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeSsisPropertiesArgs =
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeSsisPropertiesArgs.builder()
            .catalogInfo(catalogInfo?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .credential(credential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .customSetupScriptProperties(
                customSetupScriptProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .dataProxyProperties(
                dataProxyProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .edition(
                edition?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .expressCustomSetupProperties(
                expressCustomSetupProperties?.applyValue({ args0 ->
                    args0.map({ args0 -> args0 })
                }),
            )
            .licenseType(
                licenseType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .packageStores(
                packageStores?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [IntegrationRuntimeSsisPropertiesArgs].
 */
@PulumiTagMarker
public class IntegrationRuntimeSsisPropertiesArgsBuilder internal constructor() {
    private var catalogInfo: Output<IntegrationRuntimeSsisCatalogInfoArgs>? = null

    private var credential: Output<CredentialReferenceArgs>? = null

    private var customSetupScriptProperties:
        Output<IntegrationRuntimeCustomSetupScriptPropertiesArgs>? = null

    private var dataProxyProperties: Output<IntegrationRuntimeDataProxyPropertiesArgs>? = null

    private var edition: Output<Either<String, IntegrationRuntimeEdition>>? = null

    private var expressCustomSetupProperties: Output<List<Any>>? = null

    private var licenseType: Output<Either<String, IntegrationRuntimeLicenseType>>? = null

    private var packageStores: Output<List<PackageStoreArgs>>? = null

    /**
     * @param value Catalog information for managed dedicated integration runtime.
     */
    @JvmName("hbgssfwtqrwhjaty")
    public suspend fun catalogInfo(`value`: Output<IntegrationRuntimeSsisCatalogInfoArgs>) {
        this.catalogInfo = value
    }

    /**
     * @param value The credential reference containing authentication information.
     */
    @JvmName("cdthnaxedvhalljl")
    public suspend fun credential(`value`: Output<CredentialReferenceArgs>) {
        this.credential = value
    }

    /**
     * @param value Custom setup script properties for a managed dedicated integration runtime.
     */
    @JvmName("gdilawuvxcdglpkk")
    public suspend
    fun customSetupScriptProperties(`value`: Output<IntegrationRuntimeCustomSetupScriptPropertiesArgs>) {
        this.customSetupScriptProperties = value
    }

    /**
     * @param value Data proxy properties for a managed dedicated integration runtime.
     */
    @JvmName("jlkdgodbofcgkcmg")
    public suspend
    fun dataProxyProperties(`value`: Output<IntegrationRuntimeDataProxyPropertiesArgs>) {
        this.dataProxyProperties = value
    }

    /**
     * @param value The edition for the SSIS Integration Runtime
     */
    @JvmName("kqqdowfqbbeowean")
    public suspend fun edition(`value`: Output<Either<String, IntegrationRuntimeEdition>>) {
        this.edition = value
    }

    /**
     * @param value Custom setup without script properties for a SSIS integration runtime.
     */
    @JvmName("lquobrkfbynjgjbd")
    public suspend fun expressCustomSetupProperties(`value`: Output<List<Any>>) {
        this.expressCustomSetupProperties = value
    }

    @JvmName("udwiicrrpcqdwdkh")
    public suspend fun expressCustomSetupProperties(vararg values: Output<Any>) {
        this.expressCustomSetupProperties = Output.all(values.asList())
    }

    /**
     * @param values Custom setup without script properties for a SSIS integration runtime.
     */
    @JvmName("qkbjklmdqjlorsuu")
    public suspend fun expressCustomSetupProperties(values: List<Output<Any>>) {
        this.expressCustomSetupProperties = Output.all(values)
    }

    /**
     * @param value License type for bringing your own license scenario.
     */
    @JvmName("momflaxovxndmhou")
    public suspend fun licenseType(`value`: Output<Either<String, IntegrationRuntimeLicenseType>>) {
        this.licenseType = value
    }

    /**
     * @param value Package stores for the SSIS Integration Runtime.
     */
    @JvmName("prnadxtnvaosiuqv")
    public suspend fun packageStores(`value`: Output<List<PackageStoreArgs>>) {
        this.packageStores = value
    }

    @JvmName("omukvobwwahelndx")
    public suspend fun packageStores(vararg values: Output<PackageStoreArgs>) {
        this.packageStores = Output.all(values.asList())
    }

    /**
     * @param values Package stores for the SSIS Integration Runtime.
     */
    @JvmName("jvjpkphyqhxnjfqg")
    public suspend fun packageStores(values: List<Output<PackageStoreArgs>>) {
        this.packageStores = Output.all(values)
    }

    /**
     * @param value Catalog information for managed dedicated integration runtime.
     */
    @JvmName("faojvdnxrwtvjcba")
    public suspend fun catalogInfo(`value`: IntegrationRuntimeSsisCatalogInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.catalogInfo = mapped
    }

    /**
     * @param argument Catalog information for managed dedicated integration runtime.
     */
    @JvmName("ochwdwugnryjqtdk")
    public suspend
    fun catalogInfo(argument: suspend IntegrationRuntimeSsisCatalogInfoArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeSsisCatalogInfoArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.catalogInfo = mapped
    }

    /**
     * @param value The credential reference containing authentication information.
     */
    @JvmName("awnsddiaqjsjqqwl")
    public suspend fun credential(`value`: CredentialReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.credential = mapped
    }

    /**
     * @param argument The credential reference containing authentication information.
     */
    @JvmName("caiggfleoeqmpaea")
    public suspend fun credential(argument: suspend CredentialReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = CredentialReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.credential = mapped
    }

    /**
     * @param value Custom setup script properties for a managed dedicated integration runtime.
     */
    @JvmName("cqffpqbgiirtmutk")
    public suspend
    fun customSetupScriptProperties(`value`: IntegrationRuntimeCustomSetupScriptPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customSetupScriptProperties = mapped
    }

    /**
     * @param argument Custom setup script properties for a managed dedicated integration runtime.
     */
    @JvmName("itrehvuhxlxiaxei")
    public suspend
    fun customSetupScriptProperties(argument: suspend IntegrationRuntimeCustomSetupScriptPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeCustomSetupScriptPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.customSetupScriptProperties = mapped
    }

    /**
     * @param value Data proxy properties for a managed dedicated integration runtime.
     */
    @JvmName("trcnpxvmhxsaswgp")
    public suspend fun dataProxyProperties(`value`: IntegrationRuntimeDataProxyPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataProxyProperties = mapped
    }

    /**
     * @param argument Data proxy properties for a managed dedicated integration runtime.
     */
    @JvmName("dpthyganswfklqrd")
    public suspend
    fun dataProxyProperties(argument: suspend IntegrationRuntimeDataProxyPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = IntegrationRuntimeDataProxyPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dataProxyProperties = mapped
    }

    /**
     * @param value The edition for the SSIS Integration Runtime
     */
    @JvmName("swdclsqoyoeknyoy")
    public suspend fun edition(`value`: Either<String, IntegrationRuntimeEdition>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.edition = mapped
    }

    /**
     * @param value The edition for the SSIS Integration Runtime
     */
    @JvmName("gxmlsvwwvlskoejx")
    public fun edition(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IntegrationRuntimeEdition>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.edition = mapped
    }

    /**
     * @param value The edition for the SSIS Integration Runtime
     */
    @JvmName("fkvyeguweblfbrbu")
    public fun edition(`value`: IntegrationRuntimeEdition) {
        val toBeMapped = Either.ofRight<String, IntegrationRuntimeEdition>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.edition = mapped
    }

    /**
     * @param value Custom setup without script properties for a SSIS integration runtime.
     */
    @JvmName("mtorpvxotsyfybhk")
    public suspend fun expressCustomSetupProperties(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expressCustomSetupProperties = mapped
    }

    /**
     * @param values Custom setup without script properties for a SSIS integration runtime.
     */
    @JvmName("wekeugkmxishudbd")
    public suspend fun expressCustomSetupProperties(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.expressCustomSetupProperties = mapped
    }

    /**
     * @param value License type for bringing your own license scenario.
     */
    @JvmName("eglihsghpjgbuwqo")
    public suspend fun licenseType(`value`: Either<String, IntegrationRuntimeLicenseType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.licenseType = mapped
    }

    /**
     * @param value License type for bringing your own license scenario.
     */
    @JvmName("jrlpplcfniafetjh")
    public fun licenseType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IntegrationRuntimeLicenseType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.licenseType = mapped
    }

    /**
     * @param value License type for bringing your own license scenario.
     */
    @JvmName("wputygcbwrjtllfk")
    public fun licenseType(`value`: IntegrationRuntimeLicenseType) {
        val toBeMapped = Either.ofRight<String, IntegrationRuntimeLicenseType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.licenseType = mapped
    }

    /**
     * @param value Package stores for the SSIS Integration Runtime.
     */
    @JvmName("fehygwwxwwyfrwoa")
    public suspend fun packageStores(`value`: List<PackageStoreArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.packageStores = mapped
    }

    /**
     * @param argument Package stores for the SSIS Integration Runtime.
     */
    @JvmName("jgkupictemkihrup")
    public suspend fun packageStores(argument: List<suspend PackageStoreArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PackageStoreArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.packageStores = mapped
    }

    /**
     * @param argument Package stores for the SSIS Integration Runtime.
     */
    @JvmName("yruhrybhgboisajv")
    public suspend fun packageStores(vararg argument: suspend PackageStoreArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            PackageStoreArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.packageStores = mapped
    }

    /**
     * @param argument Package stores for the SSIS Integration Runtime.
     */
    @JvmName("iucgcxhfyrqpwqlx")
    public suspend fun packageStores(argument: suspend PackageStoreArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PackageStoreArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.packageStores = mapped
    }

    /**
     * @param values Package stores for the SSIS Integration Runtime.
     */
    @JvmName("gatfxoqtefncerbp")
    public suspend fun packageStores(vararg values: PackageStoreArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.packageStores = mapped
    }

    internal fun build(): IntegrationRuntimeSsisPropertiesArgs = IntegrationRuntimeSsisPropertiesArgs(
        catalogInfo = catalogInfo,
        credential = credential,
        customSetupScriptProperties = customSetupScriptProperties,
        dataProxyProperties = dataProxyProperties,
        edition = edition,
        expressCustomSetupProperties = expressCustomSetupProperties,
        licenseType = licenseType,
        packageStores = packageStores,
    )
}
